pub struct DatePatternFlags {
pub year: bool,
pub month: bool,
pub day: bool,
pub week_day: bool,
}Expand description
Flags describing the components in a DatePattern.
This data structure is used, for example, by DatePattern::validate.
Fields
year: boolmonth: boolday: boolweek_day: boolTrait Implementations
Sourceimpl Clone for DatePatternFlags
impl Clone for DatePatternFlags
Sourcefn clone(&self) -> DatePatternFlags
fn clone(&self) -> DatePatternFlags
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DatePatternFlags
impl Debug for DatePatternFlags
Sourceimpl Display for DatePatternFlags
DatePatternFlags can be converted to a String
consisting of cumulated single characters - one for each
enabled date component:
impl Display for DatePatternFlags
DatePatternFlags can be converted to a String consisting of cumulated single characters - one for each enabled date component:
use chinese_format::{*, gregorian::*};
assert_eq!(
DatePatternFlags {
year: false,
month: false,
day: false,
week_day: false
}.to_string(),
""
);
assert_eq!(
DatePatternFlags {
year: true,
month: true,
day: true,
week_day: true
}.to_string(),
"ymdw"
);
Sourceimpl Hash for DatePatternFlags
impl Hash for DatePatternFlags
Sourceimpl Ord for DatePatternFlags
impl Ord for DatePatternFlags
Sourceimpl PartialEq for DatePatternFlags
impl PartialEq for DatePatternFlags
Sourceimpl PartialOrd for DatePatternFlags
impl PartialOrd for DatePatternFlags
impl Copy for DatePatternFlags
impl Eq for DatePatternFlags
impl StructuralPartialEq for DatePatternFlags